OC.L10N.register(
    "core",
    {
    "Please select a file." : "Esbilla un ficheru, por favor.",
    "File is too big" : "El ficheru ye pergrande",
    "The selected file is not an image." : "El ficheru esbilláu nun ye una imaxe.",
    "The selected file cannot be read." : "El ficheru esbilláu nun pue lleese.",
    "Invalid file provided" : "Apurrióse un ficheru non válidu",
    "No image or file provided" : "Nun s'apurrieron imáxenes o ficheros",
    "Unknown filetype" : "Triba desconocida de ficheru",
    "Invalid image" : "Imaxe non válida",
    "An error occurred. Please contact your admin." : "Asocedió un fallu. Contauta col to alministrador, por favor.",
    "No temporary profile picture available, try again" : "Nun hai disponible imaxe de perfil temporal dala, volvi tentalo",
    "No crop data provided" : "Nun s'apurrió'l retayu de datos",
    "State token does not match" : "El pase d'estáu nun concasa",
    "Password reset is disabled" : "Ta desactiváu'l reaniciu de contraseñes",
    "Couldn't reset password because the token is invalid" : "Nun pudo reaniciase la contraseña porque'l pase nun ye válidu",
    "Couldn't reset password because the token is expired" : "Nun pudo reaniciase la contraseña porque'l caducó'l pase",
    "%s password reset" : "%s restablecer contraseña",
    "Password reset" : "Reaniciu de contrseña",
    "Click the following button to reset your password. If you have not requested the password reset, then ignore this email." : "Primi nel botón de darréu pa reaniciar la to contraseña. Si nun solicitesti esto, entós inora esti corréu.",
    "Click the following link to reset your password. If you have not requested the password reset, then ignore this email." : "Primi nel botón de darréu pa reaniciar la to contraseña. Si nun solicitesti esto, entós inora esti corréu.",
    "Preparing update" : "Tresnando anovamientu",
    "[%d / %d]: %s" : "[%d / %d]: %s",
    "Please use the command line updater because automatic updating is disabled in the config.php." : "Usa l'anovador en llinia de comandos porque l'anovamientu automáticu ta deshabilitáu nel config.php.",
    "[%d / %d]: Checking table %s" : "[%d / %d]: Comprobando tabla %s",
    "Turned on maintenance mode" : "Activóse'l mou de caltenimientu",
    "Turned off maintenance mode" : "Desactivóse'l mou de caltenimientu",
    "Maintenance mode is kept active" : "El mou caltenimientu sigue activu",
    "Updating database schema" : "Anovando esquema de base de datos",
    "Updated database" : "Base de datos anovada",
    "Checked database schema update" : "Anovamientu del esquema de base de datos revisáu",
    "Checking updates of apps" : "Comprobando anovamientu d'aplicaciones",
    "Checked database schema update for apps" : "Anovamientu del esquema de base de datos p'aplicaciones revisáu",
    "Starting code integrity check" : "Aniciando comprobación integridá del códigu",
    "Finished code integrity check" : "Finó la comprobación d'integridá del códigu",
    "%s (incompatible)" : "%s (incompatible)",
    "Following apps have been disabled: %s" : "Deshabilitáronse les aplicaciones de darréu: %s",
    "Already up to date" : "Yá s'anovó",
    "Very weak password" : "Contraseña mui feble",
    "Weak password" : "Contraseña feble",
    "So-so password" : "Contraseña pasable",
    "Good password" : "Contraseña bona",
    "Strong password" : "Contraseña mui bona",
    "PHP does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "PHP nun paez tar configuráu de mou afayadizu pa solicitar les variables del sistema. La prueba con getenv(\"PATH\") namái devuelve una rempuesta balera.",
    "This is particularly recommended when using the desktop client for file synchronisation." : "Esto aconséyase particularmente al usar el veceru d'escritoriu pa la sincronización de ficheros.",
    "Error occurred while checking server setup" : "Fallu entrín se comprobaba la configruación del sirvidor",
    "Non-existing tag #{tag}" : "Etiqueta inesistente #{tag}",
    "invisible" : "invisible",
    "({scope})" : "({scope})",
    "Delete" : "Desaniciar",
    "Rename" : "Renomar",
    "Collaborative tags" : "Etiquetes collaboratives",
    "No tags found" : "Nun s'alcontraron etiquetes",
    "unknown text" : "testu desconocíu",
    "Hello world!" : "¡Hola mundu!",
    "sunny" : "soleyero",
    "Hello {name}, the weather is {weather}" : "Hola {name}, el tiempu ta {weather}",
    "Hello {name}" : "Hola {name}",
    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Estos son los tos resultaos de gueta<script>alert(1)</script></strong>",
    "_download %n file_::_download %n files_" : ["baxar %n ficheru","baxar %n ficheros"],
    "The update is in progress, leaving this page might interrupt the process in some environments." : "L'anovamientu ta en cursu, dexar esta páxina quiciabes inerrumpa'l procesu en dellos entornos.",
    "An error occurred." : "Asocedió un fallu",
    "Please reload the page." : "Por favor, recarga la páxina",
    "Continue to Nextcloud" : "Siguir con Nextcloud",
    "Searching other places" : "Guetando otros llugares",
    "No search results in other folders for {tag}{filter}{endtag}" : "Nun hai resultaos de gueta n'otres carpetes pa {tag}{filter}{endtag}",
    "_{count} search result in another folder_::_{count} search results in other folders_" : ["{count} resultáu de gueta n'otres carpetes","{count} resultaos de gueta n'otres carpetes"],
    "Server side authentication failed!" : "Falló l'autenticación nel sirvidor!",
    "Please contact your administrator." : "Por favor, contauta col to alministrador",
    "An internal error occurred." : "Asocedió un fallu internu.",
    "Please try again or contact your administrator." : "Volvi tentalo o contauta col to alministrador, por favor.",
    "Username or email" : "Nome d'usuariu o corréu",
    "Password" : "Contraseña",
    "Log in" : "Aniciar sesión",
    "Logging in …" : "Aniciando sesión...",
    "Wrong username or password." : "Nome d'usuariu y contraseña incorreutos",
    "User disabled" : "Usuariu desactiváu",
    "Reset password" : "Restablecer contraseña",
    "Couldn't send reset email. Please contact your administrator." : "Nun pudo unviase'l corréu de reaniciu. Contauta col to alministrador, por favor.",
    "Password can not be changed. Please contact your administrator." : "Nun pue camudase la contraseña. Contauta col alministrador, por favor.",
    "New password" : "Contraseña nueva",
    "I know what I'm doing" : "Sé lo que toi faciendo",
    "Cancel" : "Encaboxar",
    "Settings" : "Axustes",
    "Search contacts …" : "Guetar contautos...",
    "No contacts found" : "Nun s'alcontraron contautos",
    "Show all contacts …" : "Amosar tolos contautos...",
    "Loading your contacts …" : "Cargando los tos contautos...",
    "Looking for {term} …" : "Guetando {term}...",
    "No" : "Non",
    "Yes" : "Sí",
    "No files in here" : "Equí nun hai ficheros",
    "New folder" : "Carpeta nueva",
    "Name" : "Nome",
    "Size" : "Tamañu",
    "Modified" : "Modificóse'l",
    "{newName} already exists" : "{newName} yá esiste",
    "Choose" : "Escoyer",
    "Copy" : "Copiar",
    "Move" : "Mover",
    "Error loading file picker template: {error}" : "Fallu cargando'l ficheru de plantía d'escoyeta: {error}",
    "OK" : "Aceutar",
    "Error loading message template: {error}" : "Fallu cargando'l mensaxe de la plantía: {error}",
    "read-only" : "namái llectura",
    "_{count} file conflict_::_{count} file conflicts_" : ["{count} conflictu de ficheru","{count} conflictos de ficheru "],
    "One file conflict" : "Conflictu nun ficheru",
    "New Files" : "Ficheros nuevos",
    "Already existing files" : "Ficheros yá esistentes",
    "Which files do you want to keep?" : "¿Qué ficheros quies caltener?",
    "If you select both versions, the copied file will have a number added to its name." : "Si seleiciones dambes versiones, el ficheru copiáu va tener un númberu amestáu al so nome",
    "Continue" : "Continuar",
    "(all selected)" : "(esbillao too)",
    "({count} selected)" : "(esbillaos {count})",
    "Error loading file exists template" : "Falu cargando plantía de ficheru esistente",
    "Pending" : "Pendiente",
    "Saving..." : "Guardando...",
    "Authentication required" : "Ríquese l'autenticación",
    "This action requires you to confirm your password" : "Esta aición rique que confirmes la to contraseña",
    "Confirm" : "Confirmar",
    "Failed to authenticate, try again" : "Falu al autenticar, volvi tentalo",
    "seconds ago" : "hai segundos",
    "Connection to server lost" : "Perdióse la conexón del sirvidor",
    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Fallu cargando la páxina, recargando en %n segundu","Fallu cargando la páxina, recargando en %n segundos"],
    "Hide details" : "Anubrir detalles",
    "No action available" : "Nun hai aiciones disponibles",
    "Error fetching contact actions" : "Fallu diendo en cata de les aiciones de contautos",
    "Personal" : "Personal",
    "Users" : "Usuarios",
    "Apps" : "Aplicaciones",
    "Admin" : "Alministrador",
    "Help" : "Ayuda",
    "Access forbidden" : "Accesu denegáu",
    "File not found" : "Nun s'alcontró'l ficheru",
    "Error" : "Fallu",
    "Internal Server Error" : "Fallu internu del sirvidor",
    "More details can be found in the server log." : "Puen alcontrase más detalles nel rexistru del sirvidor.",
    "Technical details" : "Detalle téunicos",
    "Remote Address: %s" : "Direición reota: %s",
    "Request ID: %s" : "ID de solicitú: %s",
    "Type: %s" : "Triba: %s",
    "Code: %s" : "Códigu: %s",
    "Message: %s" : "Mensaxe: %s",
    "File: %s" : "Ficheru: %s",
    "Line: %s" : "Llinia: %s",
    "Security warning" : "Alvertencia de seguranza",
    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "El to direutoriu de datos y ficheros seique ye accesible dende internet por mor qu'el ficheru .htaccess nun furrula.",
    "Create an <strong>admin account</strong>" : "Crea una <strong>cuenta d'alministrador</strong>",
    "Username" : "Nome d'usuariu",
    "Storage & database" : "Almacenamientu y Base de datos",
    "Data folder" : "Carpeta de datos",
    "Configure the database" : "Configura la base de datos",
    "Only %s is available." : "Namái ta disponible %s",
    "For more details check out the documentation." : "Pa más detalles comprueba la documentación.",
    "Database user" : "Usuariu de la base de datos",
    "Database password" : "Contraseña de la base de datos",
    "Database name" : "Nome de la base de datos",
    "Database tablespace" : "Espaciu de tables de la base de datos",
    "Database host" : "Agospiador de la base de datos",
    "Performance warning" : "Alvertencia de rindimientu",
    "Finish setup" : "Finar la configuración ",
    "Finishing …" : "Finando...",
    "Need help?" : "¿Precises ayuda?",
    "See the documentation" : "Mira la documentación",
    "More apps" : "Más aplicaciones",
    "More" : "Más",
    "Search" : "Guetar",
    "Contacts" : "Contautos",
    "Confirm your password" : "Confirma la to contraseña",
    "App token" : "Pase d'aplicación",
    "Grant access" : "Conceder accesu",
    "This share is password-protected" : "Esta compartición tien contraseña protexida",
    "The password is wrong. Try again." : "La contraseña ye incorreuta. Inténtalo otra vegada.",
    "Two-factor authentication" : "Autenticación en dos pasos",
    "Use backup code" : "Usar códigu de respaldu",
    "Error while validating your second factor" : "Fallu al validar el to pasu segundu",
    "These apps will be updated:" : "Anovaránse estes aplicaciones:",
    "These incompatible apps will be disabled:" : "Deshabilitaránse estes aplicaciones incompletes:",
    "The theme %s has been disabled." : "Deshabilitóse'l tema %s.",
    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Enantes de siguir, asegúrate de que se fizo una copia de seguridá de la base de datos, la carpeta de configuración y la carpeta de datos.",
    "Start update" : "Aniciar anovamientu",
    "Detailed logs" : "Rexistros detallaos",
    "Please use the command line updater because you have a big instance with more than 50 users." : "Usa l'anovador en llinia de comandos porque tienes una instancia grande con más de 50 usuarios.",
    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Sé que si sigo faciendo l'anovamientu pela IU web pue escosar el tiempu de la solicitú y causar una perda de datos, pero teo un respaldu y sé cómo restaurar la mio instancia en casu de fallu.",
    "Contact your system administrator if this message persists or appeared unexpectedly." : "Contauta col alministrador si esti problema sigui apaeciendo.",
    "Could not send reset email because there is no email address for this username. Please contact your administrator." : "Nun pudo unviase'l corréu de reaniciu porque nun hai direición de corréu dala pa esti nome d'usuariu. Contauta col to alministrador, por favor.",
    "Couldn't send reset email. Please make sure your username is correct." : "Nun pudo unviase'l corréu. Asegurate que'l to nome d'usuariu seya correutu, por favor",
    "Dismiss" : "Encaboxar",
    "The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "Unviósete al corréu l'enllaz pa reaniciar la to contraseña. Si nun lu recibes nuna cantidá razonable de tiempu, comprueba les tos carpetes de corréu puxarra. <br>Si nun ta ehí, entruga al to alministrador llocal",
    "Your files are encrypted. There will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" : "Los tos ficheros tán cifraos. Nun habrá mou de recuperar los datos dempués de reaniciar la to contraseña.<br />Si nun tas seguru de lo que facer, contautua col to alministrador enantes de siguir. <br />¿De xuru que quies siguir?",
    "Shared" : "Compartíu",
    "Shared by" : "Compartíos por",
    "Choose a password for the public link" : "Escueyi una contraseña pal enllaz públicu",
    "Copied!" : "¡Copióse!",
    "Copy link" : "Copiar enllaz",
    "Not supported!" : "¡Nun se sofita!",
    "Press ⌘-C to copy." : "Primi ⌘-C pa copiar.",
    "Press Ctrl-C to copy." : "Primi Ctrl-C pa copiar.",
    "Resharing is not allowed" : "Recompartir nun ta permitíu",
    "Link" : "Enllaz",
    "Password protect" : "Protexer con contraseña",
    "Allow editing" : "Permitir edición",
    "Email link to person" : "Enllaz de corréu-e a la persona",
    "Send" : "Unviar",
    "Read only" : "Namái llectura",
    "Set expiration date" : "Afitar la data de caducidá",
    "Expiration" : "Caducidá",
    "Expiration date" : "Data de caducidá",
    "Unshare" : "Dexar de compartir",
    "Share to {name}" : "Compartir con {name}",
    "Share link" : "Compartir enllaz",
    "Could not unshare" : "Nun pudo dexar de compartise",
    "Shared with you and the group {group} by {owner}" : "Compartíu contigo y col grupu {group} por {owner}",
    "Shared with you by {owner}" : "Compartíu contigo por {owner}",
    "group" : "grupu",
    "remote" : "remotu",
    "email" : "corréu",
    "Can edit" : "Pue editar",
    "Can create" : "Pue crear",
    "Can change" : "Pue camudar",
    "Can delete" : "Pue desaniciar",
    "Access control" : "Control d'accesu",
    "Error while sharing" : "Fallu mientres la compartición",
    "Share details could not be loaded for this item." : "Nun pudieron cargase los detalles de la compartición pa esti elementu.",
    "_At least {count} character is needed for autocompletion_::_At least {count} characters are needed for autocompletion_" : ["Precísase polo menos {count} caráuter pal auto-completáu","Precísense polo menos {count} caráuteres pal auto-completáu"],
    "No users or groups found for {search}" : "Nun s'alcontraron usuarios o grupos pa {search}",
    "No users found for {search}" : "Nun s'alcontraron usuarios pa {search}",
    "An error occurred. Please try again" : "Asocedió un fallu. Volvi tentalo, por favor",
    "Home" : "Aniciu",
    "Work" : "Trabayu",
    "Other" : "Otru",
    "{sharee} ({type}, {owner})" : "{sharee} ({type}, {owner})",
    "Share" : "Compartir",
    "Name or email address..." : "Nome o direición de corréu...",
    "Name or federated cloud ID..." : "Nome o ID de ñube federada...",
    "Name, federated cloud ID or email address..." : "Nome, ID de ñube federada o direición de corréu...",
    "Name..." : "Nome...",
    "Error removing share" : "Fallu desaniciando la compartición",
    "SQLite will be used as database." : "SQLite usaráse como base de datos.",
    "For larger installations we recommend to choose a different database backend." : "Pa instalaciones más grandes, aconseyamos escoyer un backend diferente de base de datos.",
    "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "Especialmente al usar el veceru d'escritoriu. Pa la sincornización de ficheros nun s'aconseya.",
    "Wrong password." : "Contraseña incorreuta",
    "New Password" : "Contraseña nueva"
},
"nplurals=2; plural=(n != 1);");
